@@ -203,7 +203,7 @@ impl PeerConnectionInternal {
                 };
 
                 let stream = match srtp_session.accept().await {
-                    Ok(stream) => Arc::new(stream),
+                    Ok(stream) => stream,
                     Err(err) => {
                         log::warn!("Failed to accept RTP {}", err);
                         return;
@@ -623,10 +623,8 @@ impl PeerConnectionInternal {
         local_transceivers: Vec<Arc<RTCRtpTransceiver>>,
         use_identity: bool,
         sdp_semantics: RTCSdpSemantics,
-    ) -> Result<sdp::session_description::SessionDescription> {
-        let d = sdp::session_description::SessionDescription::new_jsep_session_description(
-            use_identity,
-        );
+    ) -> Result<SessionDescription> {
+        let d = SessionDescription::new_jsep_session_description(use_identity);
 
         let ice_params = self.ice_gatherer.get_local_parameters().await?;
 
@@ -740,10 +738,8 @@ impl PeerConnectionInternal {
         include_unmatched: bool,
         connection_role: ConnectionRole,
         sdp_semantics: RTCSdpSemantics,
-    ) -> Result<sdp::session_description::SessionDescription> {
-        let d = sdp::session_description::SessionDescription::new_jsep_session_description(
-            use_identity,
-        );
+    ) -> Result<SessionDescription> {
+        let d = SessionDescription::new_jsep_session_description(use_identity);
 
         let ice_params = self.ice_gatherer.get_local_parameters().await?;
         let candidates = self.ice_gatherer.get_local_candidates().await?;
@@ -1042,6 +1038,7 @@ impl PeerConnectionInternal {
                                 let track = receiver
                                     .receive_for_rid(rid.as_str(), &params, ssrc)
                                     .await?;
+                                //println!("handleUndeclaredSSRC got new track: {:?}", track);
                                 RTCPeerConnection::do_track(
                                     Arc::clone(&self.on_track_handler),
                                     Some(track),
@@ -1097,6 +1094,7 @@ impl PeerConnectionInternal {
                     track.set_codec(params.codecs[0].clone()).await;
                     track.set_params(params).await;
 
+                    //println!("startReceiver got new track: {:?}", receiver.track().await);
                     RTCPeerConnection::do_track(
                         on_track_handler,
                         receiver.track().await,
