@@ -15,7 +15,7 @@ use sdp::common_description::Attribute;
 fn test_extract_fingerprint() -> Result<()> {
     //"Good Session Fingerprint"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![Attribute {
                 key: "fingerprint".to_owned(),
                 value: Some("foo bar".to_owned()),
@@ -30,8 +30,8 @@ fn test_extract_fingerprint() -> Result<()> {
 
     //"Good Media Fingerprint"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![Attribute {
                     key: "fingerprint".to_owned(),
                     value: Some("foo bar".to_owned()),
@@ -48,7 +48,7 @@ fn test_extract_fingerprint() -> Result<()> {
 
     //"No Fingerprint"
     {
-        let s = sdp::session_description::SessionDescription::default();
+        let s = SessionDescription::default();
 
         if let Err(err) = extract_fingerprint(&s) {
             assert!(Error::ErrSessionDescriptionNoFingerprint.equal(&err));
@@ -59,7 +59,7 @@ fn test_extract_fingerprint() -> Result<()> {
 
     //"Invalid Fingerprint"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![Attribute {
                 key: "fingerprint".to_owned(),
                 value: Some("foo".to_owned()),
@@ -76,12 +76,12 @@ fn test_extract_fingerprint() -> Result<()> {
 
     //"Conflicting Fingerprint"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![Attribute {
                 key: "fingerprint".to_owned(),
                 value: Some("foo".to_owned()),
             }],
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![Attribute {
                     key: "fingerprint".to_owned(),
                     value: Some("foo bar".to_owned()),
@@ -108,8 +108,8 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"Missing ice-pwd"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![Attribute {
                     key: "ice-ufrag".to_owned(),
                     value: Some(DEFAULT_UFRAG.to_owned()),
@@ -128,8 +128,8 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"Missing ice-ufrag"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![Attribute {
                     key: "ice-pwd".to_owned(),
                     value: Some(DEFAULT_PWD.to_owned()),
@@ -148,7 +148,7 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"ice details at session level"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![
                 Attribute {
                     key: "ice-ufrag".to_owned(),
@@ -170,8 +170,8 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"ice details at media level"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![
                     Attribute {
                         key: "ice-ufrag".to_owned(),
@@ -194,12 +194,12 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"Conflict ufrag"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![Attribute {
                 key: "ice-ufrag".to_owned(),
                 value: Some("invalidUfrag".to_owned()),
             }],
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![
                     Attribute {
                         key: "ice-ufrag".to_owned(),
@@ -224,12 +224,12 @@ async fn test_extract_ice_details() -> Result<()> {
 
     //"Conflict pwd"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             attributes: vec![Attribute {
                 key: "ice-pwd".to_owned(),
                 value: Some("invalidPwd".to_owned()),
             }],
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+            media_descriptions: vec![MediaDescription {
                 attributes: vec![
                     Attribute {
                         key: "ice-ufrag".to_owned(),
@@ -259,9 +259,9 @@ async fn test_extract_ice_details() -> Result<()> {
 fn test_track_details_from_sdp() -> Result<()> {
     //"Tracks unknown, audio and video with RTX"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             media_descriptions: vec![
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "foobar".to_owned(),
                         ..Default::default()
@@ -282,7 +282,7 @@ fn test_track_details_from_sdp() -> Result<()> {
                     ],
                     ..Default::default()
                 },
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "audio".to_owned(),
                         ..Default::default()
@@ -303,7 +303,7 @@ fn test_track_details_from_sdp() -> Result<()> {
                     ],
                     ..Default::default()
                 },
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "video".to_owned(),
                         ..Default::default()
@@ -332,7 +332,7 @@ fn test_track_details_from_sdp() -> Result<()> {
                     ],
                     ..Default::default()
                 },
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "video".to_owned(),
                         ..Default::default()
@@ -357,7 +357,7 @@ fn test_track_details_from_sdp() -> Result<()> {
                     ],
                     ..Default::default()
                 },
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "video".to_owned(),
                         ..Default::default()
@@ -418,9 +418,9 @@ fn test_track_details_from_sdp() -> Result<()> {
 
     //"inactive and recvonly tracks ignored"
     {
-        let s = sdp::session_description::SessionDescription {
+        let s = SessionDescription {
             media_descriptions: vec![
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "video".to_owned(),
                         ..Default::default()
@@ -437,7 +437,7 @@ fn test_track_details_from_sdp() -> Result<()> {
                     ],
                     ..Default::default()
                 },
-                sdp::media_description::MediaDescription {
+                MediaDescription {
                     media_name: MediaName {
                         media: "video".to_owned(),
                         ..Default::default()
@@ -467,8 +467,8 @@ fn test_track_details_from_sdp() -> Result<()> {
 fn test_have_application_media_section() -> Result<()> {
     //"Audio only"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 media_name: MediaName {
                     media: "audio".to_owned(),
                     ..Default::default()
@@ -493,8 +493,8 @@ fn test_have_application_media_section() -> Result<()> {
 
     //"Application"
     {
-        let s = sdp::session_description::SessionDescription {
-            media_descriptions: vec![sdp::media_description::MediaDescription {
+        let s = SessionDescription {
+            media_descriptions: vec![MediaDescription {
                 media_name: MediaName {
                     media: MEDIA_SECTION_APPLICATION.to_owned(),
                     ..Default::default()
@@ -517,7 +517,7 @@ async fn fingerprint_test(
     sdpmedia_description_fingerprints: bool,
     expected_fingerprint_count: usize,
 ) -> Result<()> {
-    let s = sdp::session_description::SessionDescription::default();
+    let s = SessionDescription::default();
 
     let dtls_fingerprints = certificate.get_fingerprints()?;
 
@@ -659,7 +659,7 @@ async fn test_populate_sdp() -> Result<()> {
             rid_map,
         }];
 
-        let d = sdp::session_description::SessionDescription::default();
+        let d = SessionDescription::default();
 
         let params = PopulateSdpParams {
             is_plan_b: false,
@@ -739,7 +739,7 @@ async fn test_populate_sdp() -> Result<()> {
             rid_map: HashMap::new(),
         }];
 
-        let d = sdp::session_description::SessionDescription::default();
+        let d = SessionDescription::default();
 
         let params = PopulateSdpParams {
             is_plan_b: false,
@@ -785,7 +785,7 @@ async fn test_populate_sdp() -> Result<()> {
 
 #[test]
 fn test_get_rids() {
-    let m = vec![sdp::media_description::MediaDescription {
+    let m = vec![MediaDescription {
         media_name: MediaName {
             media: "video".to_owned(),
             ..Default::default()
@@ -814,7 +814,7 @@ fn test_get_rids() {
 fn test_codecs_from_media_description() -> Result<()> {
     //"Codec Only"
     {
-        let codecs = codecs_from_media_description(&sdp::media_description::MediaDescription {
+        let codecs = codecs_from_media_description(&MediaDescription {
             media_name: MediaName {
                 media: "audio".to_owned(),
                 formats: vec!["111".to_owned()],
@@ -845,7 +845,7 @@ fn test_codecs_from_media_description() -> Result<()> {
 
     //"Codec with fmtp/rtcp-fb"
     {
-        let codecs = codecs_from_media_description(&sdp::media_description::MediaDescription {
+        let codecs = codecs_from_media_description(&MediaDescription {
             media_name: MediaName {
                 media: "audio".to_owned(),
                 formats: vec!["111".to_owned()],
@@ -902,25 +902,24 @@ fn test_codecs_from_media_description() -> Result<()> {
 
 #[test]
 fn test_rtp_extensions_from_media_description() -> Result<()> {
-    let extensions =
-        rtp_extensions_from_media_description(&sdp::media_description::MediaDescription {
-            media_name: MediaName {
-                media: "audio".to_owned(),
-                formats: vec!["111".to_owned()],
-                ..Default::default()
-            },
-            attributes: vec![
-                Attribute {
-                    key: "extmap".to_owned(),
-                    value: Some("1 ".to_owned() + sdp::extmap::ABS_SEND_TIME_URI),
-                },
-                Attribute {
-                    key: "extmap".to_owned(),
-                    value: Some("3 ".to_owned() + sdp::extmap::SDES_MID_URI),
-                },
-            ],
+    let extensions = rtp_extensions_from_media_description(&MediaDescription {
+        media_name: MediaName {
+            media: "audio".to_owned(),
+            formats: vec!["111".to_owned()],
             ..Default::default()
-        })?;
+        },
+        attributes: vec![
+            Attribute {
+                key: "extmap".to_owned(),
+                value: Some("1 ".to_owned() + sdp::extmap::ABS_SEND_TIME_URI),
+            },
+            Attribute {
+                key: "extmap".to_owned(),
+                value: Some("3 ".to_owned() + sdp::extmap::SDES_MID_URI),
+            },
+        ],
+        ..Default::default()
+    })?;
 
     assert_eq!(extensions[sdp::extmap::ABS_SEND_TIME_URI], 1);
     assert_eq!(extensions[sdp::extmap::SDES_MID_URI], 3);
